<?php

require_once 'grouper-ui-php/etc/config.php';
require_once 'grouper-ui-php/database.php';
require_once 'grouper-ui-php/ldap.php';
require_once 'grouper-ui-php/grouper.php';
require_once 'grouper-ui-php/lib_members.php';
require_once 'grouper-ui-php/lib_invite.php';
require_once 'grouper-ui-php/lib_request.php';

function api_request_invitations() {
	global $db;
	if (!db_connect($db)) die('could not connect to database');

	$result = array();
	if (!empty($_GET['group'])) {
		$invitations = get_invitations($db, $_GET['group']);
		if ( ($invitations !== -1) and is_array($invitations) ) {
			foreach($invitations as $id => $invitation) {
				$result[] = $invitation['mailaddress'];
			}
		}
	}
	print json_encode($result);
}

function api_request_requests() {
	global $db, $ldap;
	if (!db_connect($db)) die('could not connect to database');
  	if (!source_connect($ldap)) die('could not connect to ldap');

	$result = array();
	if (!empty($_GET['group'])) {
		$requests = get_requests($db, $_GET['group']);
		if ( ($requests !== -1) and is_array($requests) ) {
			foreach($requests as $request) {
				$uuid = $request['uuid'];
				if ($profile = source_profile($ldap, $uuid)) {
					$result[] = $profile['cn'][0];
				}
			}
		}
	}
	print json_encode($result);
}

function api_request_invite() {
	global $db;
	if (!db_connect($db)) throw new Exception('could not connect to database');
	if (empty($_POST['group'])) throw new Exception('no group parameter found');
	if (empty($_POST['subject'])) throw new Exception('no subject parameter found');
	if (empty($_POST['body'])) throw new Exception('no body parameter found');

	$group_id = $_POST['group'];
	$mail_addresses = $_POST['addresses'];
	$mail_array = explode(",", $mail_addresses);

	$group_name = $group_id;
	$subject = $_POST['subject'];
	$body = $_POST['body'];

	//TODO: move to shared function
	foreach ($mail_array as $address) {
		if (!$address = trim(stripslashes($address))) continue;
		if (!valid_address($address)) continue;
		if ($uiid = set_invitation($db, $group_id, $address, $uuid)) {
			$https = $_SERVER['HTTPS'];
			$host = $_SERVER['SERVER_NAME'];
			$url = ($https ? "https" : "http") . "://$host/process";
			$accept_url = $url . "?accept=$uiid";
			$deny_url = $url . "?deny=$uiid";
			$message = $body . "\n\n" . sprintf(LBL_INVITE_BODY_FOOTER, $accept_url, $deny_url);
			if (mail($address, stripslashes($subject), stripslashes($message), "From: systeembericht@surfteams.nl\r\nReply-To: systeembericht@surfteams.nl") ) {
				echo "ok: $address\n";
			}
		}
	}
}

function api_request_join() {
  global $db, $ldap;
  $https = $_SERVER['HTTPS'];
  $host = $_SERVER['SERVER_NAME'];
  $url = ($https ? "https" : "http") . "://$host/teams";

  if (empty($_POST['group'])) throw new Exception('no group parameter found');
  $group_id = $_POST['group'];
  if (empty($_POST['subject'])) throw new Exception('no subject parameter found');
  $subject = $_POST['subject'];
  if (empty($_POST['body'])) throw new Exception('no body parameter found');
  $body = $_POST['body'];
  if (empty($_POST['member'])) throw new Exception('no member parameter found');
  $uuid = $_POST['member'];

  $text = $body . "\n\n" . sprintf(LBL_REQUEST_BODY_FOOTER, $url);

  $bad_subjects = array('admin', 'GrouperSystem', 'GrouperAll');

  if (!source_connect($ldap)) die('could not connect to ldap');
  if (!db_connect($db)) die('could not connect to database');
  $gr = new_grouper();
  if (!$gr->isConnected()) die('could not connect to grouper');
  if (!$privs = $gr->getGroupPrivileges($group_id)) die('could not retrieve privileges');

  foreach($privs as $admin => $rights) {
    if (in_array($admin, $bad_subjects) || !in_array("admin", $rights)) continue;

    $profile = source_profile($ldap, $admin);
    if ($profile === FALSE) continue;

    for ($i = 0; $i < $profile['mail']['count']; $i++) {
      $address = $profile['mail'][$i];
      if (mail($address, $subject, $text, "From: systeembericht@surfteams.nl\r\nReply-To: systeembericht@surfteams.nl")) {
	echo "ok: $address\n";
	set_request($db, $group_id, $uuid);
      }
    }
  }
}

$request = ((array_key_exists('request', $_GET) ? $_GET['request'] : (array_key_exists('request', $_POST) ? $_POST['request'] : NULL)));
#error_log('$_GET' . print_r($_GET, TRUE) . "\n");
#error_log('$_POST' . print_r($_POST, TRUE) . "\n");
#error_log("request: $request\n");
if (isset($request)) {
	$handler = 'api_request_' . $request;
	if (function_exists($handler)) $handler();
}

?>
